function[W] = lagrangeweights(x,N)

% calculate the Lagrange polynomial weights w for a (/any) vector of positions x,
% given input data at N+1 Chebyshev points spanning -1 to 1
% 
% Output matrix w has N+1 columns, and rows numbering length(x)
% If column vector yc = ['yc(1)...yc(N+1)]' represents function data at
% Chebyshev points, then column vector y = w*yc gives interpolated values at positions x

xc = cos(pi*(0:N)/N);       % Chebyshev points, xc
X = repmat(xc,N+1,1);
DX = X-X'; 
SDX = (abs(DX)>0);          % non-zero elements of matrix
% denominator of weights
for j = 1:N+1
   w_denom(j) = prod( DX(j,find(SDX(j,:))) );
end

for i = 1:length(x)
    for j = 1:N+1
        w_numer(j) = prod( x(i) - xc(find(SDX(j,:))) );
    end
    W(i,:) = w_numer ./ w_denom;
end



