function[] = plot_results_sections_example

% plot isotopic patterns at different horizontal sections, down through a distance of one signal wavelength


% (1) load results in (r,theta)

% interpolate_results to regular theta spacing (101 grid points in theta)
Ntheta = 101;
interpolate_results_new(Ntheta);

% load results file (containing interpolated results)
load results

% prep data
RR = repmat(r,Ntheta,1);
THTH = repmat(theta,1,J);
% annular sector
XX1 = RR.*cos(THTH); XX2 = RR.*cos(THTH+L); XX3 = RR.*cos(THTH+2*L); 
YY1 = RR.*sin(THTH); YY2 = RR.*sin(THTH+L); YY3 = RR.*sin(THTH+2*L);


% (2) plot isotopic patterns at different horizontal sections

% vertical position exp(i*kz*z) for z from 0 to lam
Npos = 129;
pos = [0 : 2*pi/(Npos-1): 2*pi];

figure(1)
set(1,'PaperPosition',[0.5 0.5 22 7])
%
for j = 1:Npos
    %
    % panel (a)
    subplot(6,15,[  1,2, 16,17, 31,32, 46,47, 61,62, 76,77])    
    zvec0 = lam0*[0:0.01:1];
    zvec = zvec0/b;
    plot( real(HH((Ntheta+1)/2,end)*exp(i*kz*zvec)) , zvec0 , 'k'); hold on
    plot( real(HH(1,end)*exp(i*kz*zvec)) , zvec0 , 'Color',[0.2 0.4 1]);
    plot( real(HH(1,1)*exp(i*kz*zvec)) , zvec0 , 'r'); 
    plot( [-1.2 1.2] , lam0*pos(j)/(2*pi)*[1 1] ,'--k' ,'LineWidth',1.25); hold off
    xlim([-1.2 1.2]); xlabel('Amplitude')
    ylh = ylabel('{\itz} (m)'); ylh.Position(1) = ylh.Position(1) + 0.13;
    set(gca,'YDir','reverse')
    text(-2.6,0.0023*lam0/0.08,'(a)');
    pbaspect([1 2.6 1])
    %
    % panel (b)
    hsb = subplot(6,15,[  4:9, 19:24, 34:39, 49:54, 64:69, 79:84]);
    h = pcolor(XX1,YY1,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none'); axis equal; axis(1.05*[-1 1 -1 1]); 
    hold on
    h = pcolor(XX2,YY2,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none')
    h = pcolor(XX3,YY3,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none')
    hold off
    % title('\delta');
    xticklabels([]); xticks([]); yticklabels([]); yticks([]); 
    % flexible color scale covering the range
    caxis([min(min(real(H*exp(i*pos(j))))) max(max(real(H*exp(i*pos(j)))))]);
    text(-1.3,1,'(b)');
    chandle = colorbar;
    set(chandle,'FontSize',7.5);  
    %
    % panel (c)
    hsc = subplot(6,15,[10:15, 25:30, 40:45, 55:60, 70:75, 85:90]);
    h = pcolor(XX1,YY1,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none'); axis equal; axis(1.05*[-1 1 -1 1]); 
    hold on
    h = pcolor(XX2,YY2,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none')
    h = pcolor(XX3,YY3,real(HH*exp(i*pos(j)))); set(h, 'EdgeColor', 'none')
    hold off
    % title('\delta');
    xticklabels([]); xticks([]); yticklabels([]); yticks([]);
    % flexible color scale, BUT uses nonlinear colormap based on whether
    % amplitude at vein exceeds that in grain interior
    csign = sign( real(HH(1,1)*exp(i*pos(j))) - real(HH((Ntheta+1)/2,end)*exp(i*pos(j))) );
    cmin = min(min(real(H*exp(i*pos(j)))));
    cmax = max(max(real(H*exp(i*pos(j)))));
    if csign > 0
        caxis([ cmin cmax ]);
    elseif csign < 0
        caxis([ cmin cmax ]);
    elseif csign == 0
        caxis([ cmin cmax ]);
    end
    colormap(hsc, cmap_nonlin( csign ));
    text(-1.3,1,'(c)');
    chandle = colorbar;
    set(chandle,'FontSize',7.5); 
    %  
    %
    % nudge subplots (b) and (c) to left/right & scale: Position = [x y width height]
    hsb.Position = hsb.Position + [ -0.28 0.007 0 0 ]; hsb.Position(3) = 0.775; hsb.Position(4) = 0.775;
    hsc.Position = hsc.Position + [ -0.235 0.007 0 0 ]; hsc.Position(3) = 0.775; hsc.Position(4) = 0.775;
    %
    eval(['print -dpng -r300 sec' num2str(j)])
    pause(0.001)
end

